;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "list-utils" "20241106.1849"
  "List-manipulation utility functions."
  ()
  :url "http://github.com/rolandwalker/list-utils"
  :commit "bbea0e7cc7ab7d96e7f062014bde438aa8ffcd43"
  :revdesc "bbea0e7cc7ab"
  :keywords '("extensions")
  :authors '(("Roland Walker" . "walker@pobox.com"))
  :maintainers '(("Roland Walker" . "walker@pobox.com")))
